

ELEGIT

DEFAULT BRANCH:
git config --global init.defaultBranch o
git config --global init.defaultBranch CLIMATE

GITNURO:
https://github.com/JetpackDuba/Gitnuro

	Flathub Installation, Fedora
	https://flathub.org/setup

		Install Flathub is not already installed
		flatpak remote-add --if-not-exists flathub https://dl.flathub.org/repo/flathub.flatpakrepo
		
		Install Gitnuro
		flatpak install flathub com.jetpackduba.Gitnuro
		
		
		Start Gitnuro
		flatpak run com.jetpackduba.Gitnuro
